package com.ruoyi.interfaces.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.interfaces.mapper.MdDataItemMapper;
import com.ruoyi.interfaces.domain.MdDataItem;
import com.ruoyi.interfaces.service.IMdDataItemService;

/**
 * 数据项Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-25
 */
@Service
public class MdDataItemServiceImpl implements IMdDataItemService 
{
    @Autowired
    private MdDataItemMapper mdDataItemMapper;

    /**
     * 查询数据项
     * 
     * @param dataId 数据项主键
     * @return 数据项
     */
    @Override
    public MdDataItem selectMdDataItemByDataId(String dataId)
    {
        return mdDataItemMapper.selectMdDataItemByDataId(dataId);
    }

    /**
     * 查询数据项列表
     * 
     * @param mdDataItem 数据项
     * @return 数据项
     */
    @Override
    public List<MdDataItem> selectMdDataItemList(MdDataItem mdDataItem)
    {
        return mdDataItemMapper.selectMdDataItemList(mdDataItem);
    }

    /**
     * 新增数据项
     * 
     * @param mdDataItem 数据项
     * @return 结果
     */
    @Override
    public int insertMdDataItem(MdDataItem mdDataItem)
    {
        mdDataItem.setDataId(IdUtils.fastUUID());
        mdDataItem.setCreateby(DateUtils.getNowDate());
        return mdDataItemMapper.insertMdDataItem(mdDataItem);
    }

    /**
     * 修改数据项
     * 
     * @param mdDataItem 数据项
     * @return 结果
     */
    @Override
    public int updateMdDataItem(MdDataItem mdDataItem)
    {
        mdDataItem.setModifyby(DateUtils.getNowDate());
        return mdDataItemMapper.updateMdDataItem(mdDataItem);
    }

    /**
     * 批量删除数据项
     * 
     * @param dataIds 需要删除的数据项主键
     * @return 结果
     */
    @Override
    public int deleteMdDataItemByDataIds(String[] dataIds)
    {
        return mdDataItemMapper.deleteMdDataItemByDataIds(dataIds);
    }

    /**
     * 删除数据项信息
     * 
     * @param dataId 数据项主键
     * @return 结果
     */
    @Override
    public int deleteMdDataItemByDataId(String dataId)
    {
        return mdDataItemMapper.deleteMdDataItemByDataId(dataId);
    }
}
